@@ -1,4 +1,4 @@
-# Toby Thurston -- 07 Feb 2016 
+# Toby Thurston -- 14 Feb 2016 
 # Plot a nice picture of a series of maps
 
 use strict;
@@ -11,9 +11,10 @@ use Geo::Coordinates::OSGB::Maps qw(%maps %name_for_map_series);
 use Getopt::Long;
 use Pod::Usage;
 use File::Temp;
+use File::Spec;
 use Carp;
 
-my $version = '2.14';
+our $VERSION = '2.15';
 
 =pod
 
@@ -26,10 +27,6 @@ If you have a working TeXLive installation with GhostScript installed,
 you can use it to produce PDF index maps of the various map series
 provided by L<Geo::Coordinates::OSGB::Maps>.
 
-=head1 VERSION
-
-2.14
-
 =head1 SYNOPSIS
 
 This programme shows off several features of L<Geo::Coordinates::OSGB>.
@@ -53,7 +50,8 @@ should be one of the keys of the map series defined
 by L<Geo::Coordinates::OSGB::Maps>.  Currently: A=Landranger, 
 B=Explorer, C=One-inch, H=Harvey Mountain Maps, J=Harvey Superwalker.
 
-You can use several keys but the result may be unreadable.
+You can combine keys to get a concordance but the result may not be easy to read.
+
 Default is none - no map outlines are printed.
 
 =item --paper A[01234]
@@ -82,12 +80,13 @@ Show a few major cities in the background.  Turn off with C<--notowns>.
 
 Show the boundaries of the OSTN02 transformation dataset.  Default is off.
 
-=item --coastfile shapefile.txt
+=item --[no]coast
 
-Plot the coast line found in C<shapefile.txt>.  The input should be an ESRI
+Plot the coast line found in C<gb-coastline.shapes>.  This input is an ESRI
 shape dump file with longitude and latitude pairs on each line, and each shape
-separated by a line with a leading # character.  See the supplied shape file
-for an example. Default is C<gb-coastline.shapes>.
+separated by a line with a leading # character.  The code below shows you how to 
+read it and convert it to grid coordinates.
+Default is to show the coast lines.  Turn off with C<--nocoast>.
 
 =item --usage, help, man
 
@@ -182,7 +181,8 @@ This is easy on OSX or Linux. On Windows these functions are also provided by Mi
 
 =head1 AUTHOR
 
-Toby Thurston -- 04 Feb 2016 
+Toby Thurston -- 14 Feb 2016 
+
 toby@cpan.org
 
 =cut
@@ -193,7 +193,8 @@ my $show_grid       = 1;
 my $show_graticule  = 1;
 my $show_towns      = 1;
 my $show_ostn02     = 0;
-my $coast_shapes    = 'gb-coastline.shapes';
+my $show_coast      = 1;
+my $call_MP         = 1;
 my $pdf_filename;
 
 my $options_ok = GetOptions(
@@ -204,9 +205,10 @@ my $options_ok = GetOptions(
     'towns!'      => \$show_towns,
     'ostn!'       => \$show_ostn02,
     'outfile=s'   => \$pdf_filename,
-    'coastfile=s' => \$coast_shapes,
+    'coast!'      => \$show_coast,
+    'mpost!'      => \$call_MP,
     
-    'version'     => sub { warn "$0, version: $version\n"; exit 0; }, 
+    'version'     => sub { warn "$0, version: $VERSION\n"; exit 0; }, 
     'usage'       => sub { pod2usage(-verbose => 0, -exitstatus => 0) },                         
     'help'        => sub { pod2usage(-verbose => 1, -exitstatus => 0) },                         
     'man'         => sub { pod2usage(-verbose => 2, -exitstatus => 0) },
@@ -328,7 +330,8 @@ if ($show_grid) {
     }
 }
 
-if ( -f $coast_shapes && open my $coast, '<', $coast_shapes ) {
+my $coast_shapes = File::Spec->catpath((File::Spec->splitpath($0))[0,1], 'gb-coastline.shapes');
+if ( $show_coast && -f $coast_shapes && open my $coast, '<', $coast_shapes ) {
     print $plotter "drawoptions(withpen pencircle scaled 0.2 withcolor (0, 172/255, 226/255));\n";
     my @poly_path = ();
     LINE: while ( <$coast> ) {
@@ -373,7 +376,7 @@ if ($show_towns ) {
     }
 }
 
-if ( $series_wanted && exists $name_for_map_series{$series_wanted} ) {
+if ( $series_wanted && @sides ) { # sides will be empty if none of the maps matched series_wanted
 
     print $plotter "drawoptions(withpen pencircle scaled 0.2);defaultscale:=0.71;\n";
 
@@ -406,8 +409,13 @@ if ( $series_wanted && exists $name_for_map_series{$series_wanted} ) {
         print $plotter "draw p withcolor $map_color;\n";
     }
 
-    print $plotter sprintf "label.rt(\"%s sheet index\" infont defaultfont scaled 2, (0,%g));\n",
-      $name_for_map_series{$series_wanted}, 1300000/$scale;
+    my $y = 1300000/$scale;
+    for my $s ( split '', $series_wanted ) {
+        print $plotter sprintf "label.rt(\"%s sheet index\" infont defaultfont scaled 2, (0,%g)) withcolor %s;\n",
+                               $name_for_map_series{$s}, $y,
+                               exists $color_for{$s} ? $color_for{$s} : 'black';
+        $y -= 24;
+    }
 
     # add sheet names for Harvey maps
     if ( $series_wanted eq 'H' or $series_wanted eq 'J' ) {
@@ -425,12 +433,23 @@ if ( $series_wanted && exists $name_for_map_series{$series_wanted} ) {
 
 }
 
-my $obp_file = 'ostn02-boundary-points.txt';
-if ($show_ostn02 && -f $obp_file && open my $obp, '<', $obp_file) {
-    # Add OSTN02 boundary
-    printf $plotter 'drawoptions(withpen pencircle scaled %g withcolor (.6,.64,.84));', 900/$scale;
-    while ( <$obp> ) {
-        printf $plotter "drawdot(%g,%g);\n", map { $_*1000/$scale } split;
+my $obp_file = File::Spec->catpath((File::Spec->splitpath($0))[0,1], 'ostn-boundary-polygons.wkt');
+if ($show_ostn02) {
+    if (-f $obp_file && open my $obp, '<', $obp_file) {
+        # Add OSTN02 boundary
+        printf $plotter 'drawoptions(withcolor (.6,.64,.84));';
+        while ( <$obp> ) {
+            if ( my ($p) = $_ =~ m{\A POLYGON \s+ \(\((.*)\)\)\s*\Z}iosmx ) {
+                printf $plotter "draw %s;\n", 
+                join '--', 
+                map { sprintf '(%g, %g)', $_->[0]*1000/$scale, $_->[1]*1000/$scale }
+                map { [ split ' ' ] } split ',', $p;
+            }
+        }
+        printf $plotter 'drawoptions();';
+    }
+    else {
+        carp "No OSTN boundary shown, can't find or open $obp_file\n"
     }
 }
 
@@ -440,10 +459,12 @@ print $plotter 'setbounds currentpicture to bbox currentpicture shifted -z1 scal
 print $plotter "endfig;end.\n";
 close $plotter;
 
-system('mpost', $plotter->filename)               == 0 or croak "Metapost call failed";
-system('epstopdf', "-o=$pdf_filename", $epsfile)  == 0 or croak "epstopdf call failed";
+if ( $call_MP ) {
+    system('mpost', $plotter->filename)               == 0 or croak "Metapost call failed";
+    system('epstopdf', "-o=$pdf_filename", $epsfile)  == 0 or croak "epstopdf call failed";
 
-unlink($epsfile) or carp "Failed to delete temporary file: $epsfile, $!";
-unlink($logfile) or carp "Failed to delete temporary file: $logfile, $!";
+    unlink($epsfile) or carp "Failed to delete temporary file: $epsfile, $!";
+    unlink($logfile) or carp "Failed to delete temporary file: $logfile, $!";
 
-print "$0: Created $pdf_filename\n";
+    print "$0: Created $pdf_filename\n";
+}
